@@ -264,6 +264,25 @@ class Test:
         self.expect(lambda: regex.split("(?:b)|(?::+)", ":a:b::c"),
           "['', 'a', '', '', 'c']")
 
+        self.expect(lambda: regex.split("x", "xaxbxc"), "['', 'a', 'b', 'c']")
+        self.expect(lambda: [m for m in regex.splititer("x", "xaxbxc")],
+          "['', 'a', 'b', 'c']")
+
+        self.expect(lambda: regex.split("(?r)x", "xaxbxc"),
+          "['c', 'b', 'a', '']")
+        self.expect(lambda: [m for m in regex.splititer("(?r)x", "xaxbxc")],
+          "['c', 'b', 'a', '']")
+
+        self.expect(lambda: regex.split("(x)|(y)", "xaxbxc"),
+          "['', 'x', None, 'a', 'x', None, 'b', 'x', None, 'c']")
+        self.expect(lambda: [m for m in regex.splititer("(x)|(y)", "xaxbxc")],
+          "['', 'x', None, 'a', 'x', None, 'b', 'x', None, 'c']")
+
+        self.expect(lambda: regex.split("(?r)(x)|(y)", "xaxbxc"),
+          "['c', 'x', None, 'b', 'x', None, 'a', 'x', None, '']")
+        self.expect(lambda: [m for m in regex.splititer("(?r)(x)|(y)",
+          "xaxbxc")], "['c', 'x', None, 'b', 'x', None, 'a', 'x', None, '']")
+
     def test_qualified_re_split(self):
         self.expect(lambda: regex.split(":", ":a:b::c", 2), "['', 'a', 'b::c']")
         self.expect(lambda: regex.split(':', 'a:b:c:d', 2), "['a', 'b', 'c:d']")
@@ -459,6 +478,17 @@ class Test:
           u"\u2222")[1], "u'\u2222'")
         self.expect(lambda: regex.match(ur"(?u)([\u2222\u2223])", u"\u2222",
           regex.UNICODE)[1], "u'\u2222'")
+        self.expect(lambda: u"".join(regex.findall(u".",
+          u"e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
+          r"u'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
+        self.expect(lambda:
+          u"".join(regex.findall(u"[e\xe8\xe9\xea\xeb\u0113\u011b\u0117]",
+          u"e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
+          r"u'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
+        self.expect(lambda:
+          u"".join(regex.findall(u"e|\xe8|\xe9|\xea|\xeb|\u0113|\u011b|\u0117",
+          u"e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
+          r"u'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
 
     def test_anyall(self):
         self.expect(lambda: regex.match("a.b", "a\nb", regex.DOTALL)[0],
@@ -875,7 +905,99 @@ class Test:
 
     def test_search_reverse(self):
         self.expect(lambda: regex.findall(r"(?r).", "abc"), "['c', 'b', 'a']")
+        self.expect(lambda: regex.findall(r"(?r).", "abc", overlapped=True),
+          "['c', 'b', 'a']")
         self.expect(lambda: regex.findall(r"(?r)..", "abcde"), "['de', 'bc']")
+        self.expect(lambda: regex.findall(r"(?r)..", "abcde", overlapped=True),
+          "['de', 'cd', 'bc', 'ab']")
+
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?r).", "abc")],
+          "['c', 'b', 'a']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?r)..", "abcde",
+          overlapped=True)], "['de', 'cd', 'bc', 'ab']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?r).",
+          "abc")],"['c', 'b', 'a']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?r)..", "abcde",
+          overlapped=True)],"['de', 'cd', 'bc', 'ab']")
+
+        self.expect(lambda: regex.findall(r"^|\w+", "foo bar"),
+          "['', 'foo', 'bar']")
+        self.expect(lambda: regex.findall(r"(?z)^|\w+", "foo bar"),
+          "['', 'foo', 'bar']")
+        self.expect(lambda: regex.findall(r"(?r)^|\w+", "foo bar"),
+          "['bar', 'foo', '']")
+        self.expect(lambda: regex.findall(r"(?rz)^|\w+", "foo bar"),
+          "['bar', 'foo', '']")
+
+        self.expect(lambda: [m[0] for m in regex.finditer(r"^|\w+", "foo bar")],
+          "['', 'foo', 'bar']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?z)^|\w+",
+          "foo bar")], "['', 'foo', 'bar']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?r)^|\w+",
+          "foo bar")], "['bar', 'foo', '']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?rz)^|\w+",
+          "foo bar")], "['bar', 'foo', '']")
+
+        self.expect(lambda: regex.findall(r"\G\w{2}", "abcd ef"),
+          "['ab', 'cd']")
+        self.expect(lambda: regex.findall(r".{2}(?<=\G.*)", "abcd"),
+          "['ab', 'cd']")
+        self.expect(lambda: regex.findall(r"(?r)\G\w{2}", "abcd ef"),
+          "[]")
+        self.expect(lambda: regex.findall(r"(?r)\w{2}\G", "abcd ef"),
+          "['ef']")
+
+        self.expect(lambda: regex.findall(r"q*", "qqwe"),
+          "['qq', '', '', '']")
+        self.expect(lambda: regex.findall(r"(?z)q*", "qqwe"),
+          "['qq', '', '', '']")
+        self.expect(lambda: regex.findall(r"(?r)q*", "qqwe"),
+          "['', '', 'qq', '']")
+        self.expect(lambda: regex.findall(r"(?rz)q*", "qqwe"),
+          "['', '', 'qq', '']")
+
+        self.expect(lambda: regex.findall(".", "abcd", pos=1, endpos=3),
+          "['b', 'c']")
+        self.expect(lambda: regex.findall(".", "abcd", pos=1, endpos=-1),
+          "['b', 'c']")
+        self.expect(lambda: [m[0] for m in regex.finditer(".", "abcd", pos=1,
+          endpos=3)], "['b', 'c']")
+        self.expect(lambda: [m[0] for m in regex.finditer(".", "abcd", pos=1,
+          endpos=-1)], "['b', 'c']")
+
+        self.expect(lambda: [m[0] for m in regex.finditer("(?r).", "abcd",
+          pos=1, endpos=3)], "['c', 'b']")
+        self.expect(lambda: [m[0] for m in regex.finditer("(?r).", "abcd",
+          pos=1, endpos=-1)], "['c', 'b']")
+        self.expect(lambda: regex.findall("(?r).", "abcd", pos=1, endpos=3),
+          "['c', 'b']")
+        self.expect(lambda: regex.findall("(?r).", "abcd", pos=1, endpos=-1),
+          "['c', 'b']")
+
+        self.expect(lambda: regex.findall(r"[ab]", "aB", regex.I), "['a', 'B']")
+        self.expect(lambda: regex.findall(r"(?r)[ab]", "aB", regex.I),
+          "['B', 'a']")
+
+        self.expect(lambda: regex.findall(r"(?r).{2}", "abc"), "['bc']")
+        self.expect(lambda: regex.findall(r"(?r).{2}", "abc", overlapped=True),
+          "['bc', 'ab']")
+        self.expect(lambda: regex.findall(r"(\w+) (\w+)",
+          "first second third fourth fifth"),
+          "[('first', 'second'), ('third', 'fourth')]")
+        self.expect(lambda: regex.findall(r"(?r)(\w+) (\w+)",
+          "first second third fourth fifth"),
+          "[('fourth', 'fifth'), ('second', 'third')]")
+
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?r).{2}", "abc")],
+          "['bc']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?r).{2}", "abc",
+          overlapped=True)], "['bc', 'ab']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(\w+) (\w+)",
+          "first second third fourth fifth")],
+          "['first second', 'third fourth']")
+        self.expect(lambda: [m[0] for m in regex.finditer(r"(?r)(\w+) (\w+)",
+          "first second third fourth fifth")],
+          "['fourth fifth', 'second third']")
 
     def test_atomic(self):
         # Issue 433030.
@@ -933,6 +1055,24 @@ class Test:
         self.expect(lambda: [m[0] for m in
           regex.finditer(r"(?rz)^|\w+", "foo bar")], "['bar', 'foo', '']")
 
+        self.expect(lambda: regex.split("", "xaxbxc"), "['xaxbxc']")
+        self.expect(lambda: [m for m in regex.splititer("", "xaxbxc")],
+          "['xaxbxc']")
+
+        self.expect(lambda: regex.split("(?r)", "xaxbxc"), "['xaxbxc']")
+        self.expect(lambda: [m for m in regex.splititer("(?r)", "xaxbxc")],
+          "['xaxbxc']")
+
+        self.expect(lambda: regex.split("(?z)", "xaxbxc"),
+          "['', 'x', 'a', 'x', 'b', 'x', 'c', '']")
+        self.expect(lambda: [m for m in regex.splititer("(?z)", "xaxbxc")],
+          "['', 'x', 'a', 'x', 'b', 'x', 'c', '']")
+
+        self.expect(lambda: regex.split("(?rz)", "xaxbxc"),
+          "['', 'c', 'x', 'b', 'x', 'a', 'x', '']")
+        self.expect(lambda: [m for m in regex.splititer("(?rz)", "xaxbxc")],
+          "['', 'c', 'x', 'b', 'x', 'a', 'x', '']")
+
     def test_scoped_and_inline_flags(self):
         # Issues 433028, #433024, #433027.
         self.expect(lambda: regex.search(r"(?i)Ab", "ab").span(), "(0, 2)")
@@ -1754,6 +1894,7 @@ xyzabc
                 performed_count += 1
                 self.index = 0
                 print self.performing
+                sys.stdout.flush()
                 obj()
 
         print 
